@@ -1,40 +1,53 @@
-#' This package provides functions to test for a global group effect in functional gene sets.
+#' Global tests for expression data of high-dimensional sets of molecular features.
 #'
 #' \tabular{ll}{
 #' Package: \tab RepeatedHighDim\cr
 #' Type: \tab Package\cr
-#' Version: \tab 1.01\cr
-#' Date: \tab 2013-03-11\cr
+#' Version: \tab 2.0.0\cr
+#' Date: \tab 2013-08-21\cr
 #' License: \tab GPL (>= 2)\cr
 #' LazyLoad: \tab yes\cr
 #' }
 #'
-#' This package provides functions to test for a global group effect in functional gene sets.
+#' Global tests for expression data of high-dimensional sets of molecular features.
 #'
 #' @name RepeatedHighDim-package
 #' @aliases RepeatedHighDim-package
 #' @docType package
-#' @title Global test for high-dimensional data
+#' @title Global tests for expression data of high-dimensional sets of molecular features.
 #' @author Klaus Jung \email{Klaus.Jung@@ams.med.uni-goettingen.de}
 #' @keywords package
 #' @examples
+#' ### Global comparison of a set of 100 genes between two experimental groups.
 #' X1 = matrix(rnorm(1000, 0, 1), 10, 100)
 #' X2 = matrix(rnorm(1000, 0.1, 1), 10, 100)
 #' RHD = RepeatedHighDim(X1, X2, paired=FALSE)
 #' summary(RHD)
+#'
+#' ### Global comparison of a set of 100 proteins between two experimental groups,
+#' ### where (tau * 100) percent of expression levels are missing.
+#' n1 = 10
+#' n2 = 10
+#' d = 100
+#' tau = 0.1
+#' X1 = t(matrix(rnorm(n1*d, 0, 1), n1, d))
+#' X2 = t(matrix(rnorm(n2*d, 0.1, 1), n2, d))
+#' X1[sample(1:(n1*d), tau * (n1*d))] = NA
+#' X2[sample(1:(n2*d), tau * (n2*d))] = NA
+#' GlobTestMissing(X1, X2, nperm=100)
 NA
 
 
 
 #' Calculation of test statistic
 #'
-#' Calculates the test statistic in the case of paired samples.
+#' Calculates the test statistic for RepeatedHighDim in the case of paired samples.
 #'
-#' @param Y Matrix with differences of paires. Rows represent genes, columns represent samples.
+#' @param Y Matrix with differences of paires. Rows represent features (e.g. genes, proteins,...), columns represent samples.
 #' @param H Hypothesis matrix.
 #' @return A list containing the following items:
 #'   \item{k}{Indicates whether the paired or unpaired case was tested.}
-#'   \item{d}{Number of genes.}
+#'   \item{d}{Number of features.}
 #'   \item{n1}{Number of samples in group 1.}
 #'   \item{n2}{Number of samples in group 2.}
 #'   \item{Fn}{Test statistic.}
@@ -49,6 +62,7 @@ NA
 #'	\item{Jung K, Becker B, Brunner B and Beissbarth T (2011) Comparison of Global Tests for Functional Gene Sets in Two-Group Designs and Selection of Potentially Effect-causing Genes. Bioinformatics, 27: 1377-1383.}
 #' }
 #' @examples
+#' ### Global comparison of a set of 100 genes between two experimental groups.
 #' X1 = matrix(rnorm(1000, 0, 1), 10, 100)
 #' X2 = matrix(rnorm(1000, 0.1, 1), 10, 100)
 #' RHD = RepeatedHighDim(X1, X2, paired=FALSE)
@@ -78,13 +92,13 @@ TestStatSimple = function(Y, H) {
 
 #' Calculation of test statistic
 #'
-#' Calculates the test statistic in the case of unpaired samples.
+#' Calculates the test statistic for RepeatedHighDim in the case of unpaired samples.
 #'
-#' @param Y1 Matrix of expression levels in first group. Rows represent genes, columns represent samples.
-#' @param Y2 Matrix of expression levels in second group. Rows represent genes, columns represent samples.
+#' @param Y1 Matrix of expression levels in first group. Rows represent features (e.g. genes, proteins,...), columns represent samples.
+#' @param Y2 Matrix of expression levels in second group. Rows represent features (e.g. genes, proteins,...), columns represent samples.
 #' @return A list containing the following items:
 #'   \item{k}{Indicates whether the paired or unpaired case was tested.}
-#'   \item{d}{Number of genes.}
+#'   \item{d}{Number of features.}
 #'   \item{n1}{Number of samples in group 1.}
 #'   \item{n2}{Number of samples in group 2.}
 #'   \item{Fn}{Test statistic.}
@@ -99,6 +113,7 @@ TestStatSimple = function(Y, H) {
 #'	\item{Jung K, Becker B, Brunner B and Beissbarth T (2011) Comparison of Global Tests for Functional Gene Sets in Two-Group Designs and Selection of Potentially Effect-causing Genes. Bioinformatics, 27: 1377-1383.}
 #' }
 #' @examples
+#' ### Global comparison of a set of 100 genes between two experimental groups.
 #' X1 = matrix(rnorm(1000, 0, 1), 10, 100)
 #' X2 = matrix(rnorm(1000, 0.1, 1), 10, 100)
 #' RHD = RepeatedHighDim(X1, X2, paired=FALSE)
@@ -168,12 +183,12 @@ TestStatSP = function(Y1, Y2) {
 
 #' Detection of global group effect
 #'
-#' Detects global group effect between the samples of two groups (paired or unpaired).
+#' Global test for a set of molecular features (e.g. genes, proteins,...) between two experimental groups. Paired or unpaired design is allowed.
 #'
-#' @param X1 Matrix of expression levels in first group. Rows represent genes, columns represent samples.
-#' @param X2 Matrix of expression levels in second group. Rows represent genes, columns represent samples.
+#' @param X1 Matrix of expression levels in first group. Rows represent features, columns represent samples.
+#' @param X2 Matrix of expression levels in second group. Rows represent features, columns represent samples.
 #' @param paired FALSE if samples are unpaired, TRUE if samples are paired.
-#' @return An object that contains the test results. Contents can be displayes by the summary function.
+#' @return An object that contains the test results. Contents can be displayed by the summary function.
 #' @export
 #' @author Klaus Jung \email{Klaus.Jung@@ams.med.uni-goettingen.de}
 #' @references
@@ -182,6 +197,7 @@ TestStatSP = function(Y1, Y2) {
 #'	\item{Jung K, Becker B, Brunner B and Beissbarth T (2011) Comparison of Global Tests for Functional Gene Sets in Two-Group Designs and Selection of Potentially Effect-causing Genes. Bioinformatics, 27: 1377-1383.}
 #' }
 #' @examples
+#' ### Global comparison of a set of 100 genes between two experimental groups.
 #' X1 = matrix(rnorm(1000, 0, 1), 10, 100)
 #' X2 = matrix(rnorm(1000, 0.1, 1), 10, 100)
 #' RHD = RepeatedHighDim(X1, X2, paired=FALSE)
@@ -227,6 +243,7 @@ RepeatedHighDim = function(X1, X2, paired=TRUE) {
 #'	\item{Jung K, Becker B, Brunner B and Beissbarth T (2011) Comparison of Global Tests for Functional Gene Sets in Two-Group Designs and Selection of Potentially Effect-causing Genes. Bioinformatics, 27: 1377-1383.}
 #' }
 #' @examples
+#' ### Global comparison of a set of 100 genes between two experimental groups.
 #' X1 = matrix(rnorm(1000, 0, 1), 10, 100)
 #' X2 = matrix(rnorm(1000, 0.1, 1), 10, 100)
 #' RHD = RepeatedHighDim(X1, X2, paired=FALSE)
@@ -241,3 +258,69 @@ summary.RHD = function(object, ...) {
 	cat("\n")
 	print(A)
 }
+
+
+#' Detection of global group effect
+#'
+#' Tests a global effect for a set of molecular features (e.g. genes, proteins,...) between the two groups of samples. Missing values are allowd in the expression data. Samples of the two groups are supposed to be unpaired.
+#'
+#' @param X1 Matrix of expression levels in first group. Rows represent features, columns represent samples.
+#' @param X2 Matrix of expression levels in second group. Rows represent features, columns represent samples.
+#' @param nperm Number of permutations.
+#' @return The p-value of a permutation test.
+#' @export
+#' @author Klaus Jung \email{Klaus.Jung@@ams.med.uni-goettingen.de}
+#' @examples
+#' ### Global comparison of a set of 100 proteins between two experimental groups,
+#' ### where (tau * 100) percent of expression levels are missing.
+#' n1 = 10
+#' n2 = 10
+#' d = 100
+#' tau = 0.1
+#' X1 = t(matrix(rnorm(n1*d, 0, 1), n1, d))
+#' X2 = t(matrix(rnorm(n2*d, 0.1, 1), n2, d))
+#' X1[sample(1:(n1*d), tau * (n1*d))] = NA
+#' X2[sample(1:(n2*d), tau * (n2*d))] = NA
+#' GlobTestMissing(X1, X2, nperm=100)
+GlobTestMissing = function(X1, X2, nperm=100) {
+	d = dim(X1)[1]
+	n1 = dim(X1)[2]
+	n2 = dim(X2)[2]
+	n = n1 + n2
+	x = c(as.vector(X1), as.vector(X2))
+	group = c(rep(1, d*n1), rep(2, d*n2))
+	feature = c(rep(1:d, n1), rep(1:d, n2))
+	individual = gl(n, d)
+
+	index = which(!is.na(x))
+	x2 = x[index]
+	group2 = group[index]
+	feature2 = feature[index]
+	individual2 = individual[index]
+
+	K = summary(lme(x2 ~ group2 * feature2, random = ~ 1 | individual2))
+	A = anova(K)
+	P1 = A[[4]][4]
+	Pperm = rep(0, nperm)
+	Z = cbind(X1, X2)
+	for (t in 1:nperm) {
+		s = sample(1:n, n, replace=FALSE)
+		Z = Z[,s]
+		Y1 = Z[,1:n1]
+		Y2 = Z[,(n1+1):n]
+		x = c(as.vector(Y1), as.vector(Y2))
+		individual = s %x% rep(1, d)
+
+		index = which(!is.na(x))
+		x2 = x[index]
+		group2 = group[index]
+		feature2 = feature[index]
+		individual2 = individual[index]
+
+		K = summary(lme(x2 ~ group2 * feature2, random = ~ 1 | individual2))
+		A = anova(K)
+		Pperm[t] = A[[4]][4]
+	}
+	P = sum(P1>Pperm) / nperm
+	return(list(pval=P))
+}
\ No newline at end of file
